# Box Info by Homey
from twisted.internet import reactor
from twisted.web2 import server, channel, static, resource, stream, http_headers, responsecode, http

from Components.Harddisk import Harddisk
from Components.NimManager import nimmanager
from Components.About import about

from Tools.DreamboxHardware import getFPVersion

from ServiceReference import ServiceReference
from enigma import iServiceInformation

from Components.config import config, getConfigListEntry

__version__ = "0.1"

class BoxInfo(resource.Resource):
    
    title = "DreamBox 7025 - Box Info"
    sessions = [ ]
    
    def __init__(self,sessions):
    	self.sessions=sessions
        
    def render(self, req):

    	#Get Enigma Version
    	em_version = _("Enigma v%s") % about.getVersionString()

    	#Get Network Info
    	def ConvertIP(AddStr):
			retstr = AddStr.replace(', ','.')
			retstr = retstr.replace('[','')
			retstr = retstr.replace(']','')
			return retstr

    	LAN_dhcp = _("Use DHCP %s") % config.network.dhcp.value
    	LAN_ip = ConvertIP(_("IP Address %s") % config.network.ip.value)
    	LAN_netmask = ConvertIP(_("Netmask %s") % config.network.netmask.value)
    	LAN_gateway = ConvertIP(_("Gateway %s") % config.network.gateway.value)
    	LAN_dns = ConvertIP(_("Nameserver %s") % config.network.dns.value)

    	#Get FrontProcessor Version
    	fp_version = getFPVersion()
    	if fp_version is None:
			fp_version = "?"
    	else:
			fp_version = _("Frontprocessor version: %d") % fp_version

    	#Get Tuner Info
    	nims = nimmanager.nimList()
    	tunerA = nims[0][0]
    	tunerB = nims[1][0]
    	tunerinfo = _("Detected NIMs: </br>%s</br>%s") % (tunerA,tunerB)

    	#Get HDD Info
    	hdddata = Harddisk(0)
    	if hdddata.model() != "":
			hddinfo = _("Detected HDD: </br>%s (%s, %d MB free)") % (hdddata.model(), hdddata.capacity(),hdddata.free())
    	else:			
			hddinfo = "None"

    	#Get Service Info
    	service = self.sessions[0].nav.getCurrentService()

    	if self.sessions[0].nav.getCurrentlyPlayingServiceReference() is not None:
			Name = ServiceReference(self.sessions[0].nav.getCurrentlyPlayingServiceReference()).getServiceName()
    	else:
			Name = "N/A"

    	if service is not None:
			svinfo = service.info()
			svfeinfo = service.frontendInfo()
    	else:
			svinfo = None
			svfeinfo = None

    	# Get Service Info
    	Provider = svinfo.getInfoString(iServiceInformation.sProvider)
    	Videoformat = svinfo.getInfo(iServiceInformation.sAspect)
    	Namespace = hex(svinfo.getInfo(iServiceInformation.sNamespace))

    	# Get PIDs
    	VideoPID_h = hex(svinfo.getInfo(iServiceInformation.sVideoPID))
    	VideoPID_n = svinfo.getInfo(iServiceInformation.sVideoPID)
    	AudioPID_h = hex(svinfo.getInfo(iServiceInformation.sAudioPID))
    	AudioPID_n = svinfo.getInfo(iServiceInformation.sAudioPID)
    	PCRPID_h = hex(svinfo.getInfo(iServiceInformation.sPCRPID))
    	PCRPID_n = svinfo.getInfo(iServiceInformation.sPCRPID)
    	PMTPID_h = hex(svinfo.getInfo(iServiceInformation.sPMTPID))
    	PMTPID_n = svinfo.getInfo(iServiceInformation.sPMTPID)
    	TXTPID_h = hex(svinfo.getInfo(iServiceInformation.sTXTPID))
    	TXTPID_n = svinfo.getInfo(iServiceInformation.sTXTPID)
    	TSID_h = hex(svinfo.getInfo(iServiceInformation.sTSID))
    	TSID_n = svinfo.getInfo(iServiceInformation.sTSID)
    	ONID_h = hex(svinfo.getInfo(iServiceInformation.sONID))
    	ONID_n = svinfo.getInfo(iServiceInformation.sONID)
    	SID_h = hex(svinfo.getInfo(iServiceInformation.sSID))
    	SID_n = svinfo.getInfo(iServiceInformation.sSID)

    	html  = "<html><head><title>%s</title><link href=\"/webdata/theme.css\" type=\"text/css\" rel=\"stylesheet\"></link><script type=\"text/javascript\" src=\"/webdata/vlcplayer.js\"></script></head>" %self.title
    	html += "<body>"
    	html += "<table align=\"center\" border=\"0\" width=\"80%\">"
    	html += "<tr>"
    	html += "<td align=\"left\" width=\"50%\" valign=\"top\">"
    	html += "<table align=\"center\" border=\"0\" width=\"100%\">"
    	html += "<tr>"
    	html += "<td align=\"left\"></br></td>"
    	html += "</tr>"
    	html += "<tr>"
    	html += "<td align=\"left\"><b>Box Info:</b></td>"
    	html += "</tr>"
    	html += "<tr>"
    	html += "<td align=\"left\">%s</td>" % em_version
    	html += "</tr>"
    	html += "<tr>"
    	html += "<td align=\"left\">%s</td>" % fp_version
    	html += "</tr>"
    	html += "<tr>"
    	html += "<td align=\"left\"></br></td>"
    	html += "</tr>"
    	html += "<tr>"
    	html += "<td align=\"left\">%s</td>" % tunerinfo
    	html += "</tr>"
    	html += "<tr>"
    	html += "<td align=\"left\"></br></td>"
    	html += "</tr>"
    	html += "<tr>"
    	html += "<td align=\"left\">%s</td>" % hddinfo
    	html += "</tr>"
    	html += "<tr>"
    	html += "<td align=\"left\"></br></td>"
    	html += "</tr>"
    	html += "<tr>"
    	html += "<td align=\"left\"><b>LAN Info:</b></td>"
    	html += "</tr>"
    	html += "<tr>"
    	html += "<td align=\"left\">%s</td>" % LAN_dhcp
    	html += "</tr>"
    	html += "<tr>"
    	html += "<td align=\"left\">%s</td>" % LAN_ip
    	html += "</tr>"
    	html += "<tr>"
    	html += "<td align=\"left\">%s</td>" % LAN_netmask
    	html += "</tr>"
    	html += "<tr>"
    	html += "<td align=\"left\">%s</td>" % LAN_gateway
    	html += "</tr>"
    	html += "<tr>"
    	html += "<td align=\"left\">%s</td>" % LAN_dns
    	html += "</tr>"
    	html +="</table>"
    	html += "</td>"
    	html += "<td align=\"left\" width=\"50%\" valign=\"top\">"
    	html += "<table align=\"center\" border=\"0\" width=\"100%\">"
    	html += "<tr>"
    	html += "<td align=\"left\"></br></td>"
    	html += "</tr>"
    	html += "<tr>"
    	html += "<td align=\"left\"><b>Service Info:</b></td>"
    	html += "</tr>"
    	html += "<tr>"
    	html += "<td align=\"left\">Name: %s</td>" % Name
    	html += "</tr>"
    	html += "<tr>"
    	html += "<td align=\"left\">Provider: %s</td>" % Provider
    	html += "</tr>"
    	html += "<tr>"
    	html += "<td align=\"left\">Videoformat: %s</td>" % Videoformat
    	html += "</tr>"
    	html += "<tr>"
    	html += "<td align=\"left\">Namespace: %s</td>" % Namespace
    	html += "</tr>"
    	html += "<tr>"
    	html += "<td align=\"left\"></br></td>"
    	html += "</tr>"
    	html += "<tr>"
    	html += "<td align=\"left\"><b>PIDs:</b></td>"
    	html += "</tr>"
    	html += "<tr>"
    	html += "<td align=\"left\">VideoPID: %s (%sd)</td>" % (VideoPID_h,VideoPID_n)
    	html += "</tr>"
    	html += "<tr>"
    	html += "<td align=\"left\">AudioPID: %s (%sd)</td>" % (AudioPID_h,AudioPID_n)
    	html += "</tr>"
    	html += "<tr>"
    	html += "<td align=\"left\">PCRPID: %s (%sd)</td>" % (PCRPID_h,PCRPID_n)
    	html += "</tr>"
    	html += "<tr>"
    	html += "<td align=\"left\">PMTPID: %s (%sd)</td>" % (PMTPID_h,PMTPID_n)
    	html += "</tr>"
    	html += "<tr>"
    	html += "<td align=\"left\">TXTPID: %s (%sd)</td>" % (TXTPID_h,TXTPID_n)
    	html += "</tr>"
    	html += "<tr>"
    	html += "<td align=\"left\">TSID: %s (%sd)</td>" % (TSID_h,TSID_n)
    	html += "</tr>"
    	html += "<tr>"
    	html += "<td align=\"left\">ONID: %s (%sd)</td>" % (ONID_h,ONID_n)
    	html += "</tr>"
    	html += "<tr>"
    	html += "<td align=\"left\">SID: %s (%sd)</td>" % (SID_h,SID_n)
    	html += "</tr>"
    	html +="</table>"
    	html +="</body>"
    	html +="</html>"

    	return http.Response(responsecode.OK, {'Content-type': http_headers.MimeType('text', 'html')},stream=html)
